import argparse
from rrnafinder.pipeline import rRNAFinder_main

def main():

    # argument parse
    parser = argparse.ArgumentParser(
        prog='rRNAFinder', description='Find rRNA unit and all rRNA in genome\n'
    )


    parser.add_argument('fasta_file', type=str, help='a fasta file')
    parser.add_argument('-s', '--query_rRNA_seq', type=str, default=None,
                          help='a known rRNA unit seq from close species')
    parser.add_argument('-b', '--query_rRNA_bed', type=str, default=None,
                          help='bed file for close rRNA unit seq')
    parser.add_argument('-l', '--log_file', type=str,
                          help='path for log file (default: None)', default=None)
    parser.add_argument('-o', '--output_dir', type=str, help='output prefix (default: rRNA_finder)',
                          default='rRNA_finder')

    args = parser.parse_args()

    rRNAFinder_main(args)

if __name__ == '__main__':
    main()


# coding utf8
import setuptools
from rrnafinder.versions import get_versions

with open('README.md') as f:
    LONG_DESCRIPTION = f.read()

setuptools.setup(
    name="rRNAFinder",
    version=get_versions(),
    author="Yuxing Xu",
    author_email="xuyuxing@mail.kib.ac.cn",
    description="A python tool for identify rRNA gene in plant genome.",
    long_description=LONG_DESCRIPTION,
    long_description_content_type='text/markdown',
    url="https://github.com/SouthernCD/rRNAFinder",
    include_package_data = True,

    entry_points={
        "console_scripts": ["rRNAFinder = rrnafinder.cli:main"]
    },

    packages=setuptools.find_packages(),

    install_requires=[
        "toolbiox>=0.0.40",
        "hugep2g>=1.0.1",
        "bcbio-gff>=0.6.6",
        "biopython<=1.80",
    ],

    python_requires='>=3.5',
)